<?php

namespace Drp\NativeEventApp\Exceptions;

use Drp\NativeEventApp\Enums\AuthMethod;
use GraphQL\Error\ClientAware;
use Illuminate\Http\Response;
use Nuwave\Lighthouse\Exceptions\RendersErrorsExtensions;
use Throwable;

class CouldNotSendAuthCode extends \Exception implements ClientAware, RendersErrorsExtensions
{
    public static function invalidAuthMethod(AuthMethod $authMethod): self
    {
        return new self(
            "The selected auth method ($authMethod) is not permitted",
            Response::HTTP_BAD_REQUEST
        );
    }

    public static function viaMethod(AuthMethod $authMethod, ?Throwable $previous): self
    {
        return new self(
            'The Auth code could not be sent via ' . $authMethod->description,
            Response::HTTP_INTERNAL_SERVER_ERROR,
            $previous
        );
    }

    public static function viaSms(Throwable $exception): self
    {
        return new self(
            'The Auth code could not be sent via SMS',
            $exception->getCode(),
            $exception
        );
    }

    public static function viaEmail(Throwable $exception): self
    {
        return new self(
            'The Auth code could not be sent via email',
            Response::HTTP_INTERNAL_SERVER_ERROR,
            $exception
        );
    }

    public static function invalidEmail(Throwable $exception): self
    {
        return new self('The Auth code could not be sent via email', Response::HTTP_BAD_REQUEST, $exception);
    }

    public function isClientSafe(): bool
    {
        return true;
    }

    public function getCategory(): string
    {
        return 'auth';
    }

    public function extensionsContent(): array
    {
        return [
            'hint' => optional($this->getPrevious())->getMessage(),
        ];
    }
}
